Zeta functions, L-series and polylogarithms
-------------------------------------------

This section includes the Riemann zeta functions and associated functions
pertaining to analytic number theory.


Riemann and Hurwitz zeta functions
..................................

.. autofunction:: mpmath.zeta


Dirichlet L-series
..................

.. autofunction:: mpmath.altzeta
.. autofunction:: mpmath.dirichlet


Stieltjes constants
...................

.. autofunction:: mpmath.stieltjes


Zeta function zeros
...................

These functions are used for the study of the Riemann zeta function in the
critical strip.

.. autofunction:: mpmath.zetazero
.. autofunction:: mpmath.nzeros
.. autofunction:: mpmath.siegelz
.. autofunction:: mpmath.siegeltheta
.. autofunction:: mpmath.grampoint
.. autofunction:: mpmath.backlunds


Lerch transcendent
..................

.. autofunction:: mpmath.lerchphi


Polylogarithms and Clausen functions
....................................

.. autofunction:: mpmath.polylog
.. autofunction:: mpmath.clsin
.. autofunction:: mpmath.clcos
.. autofunction:: mpmath.polyexp


Zeta function variants
......................

.. autofunction:: mpmath.primezeta
.. autofunction:: mpmath.secondzeta
